Module dataflow

Module dataflow 

Dataflow retrieval: trace variable origins via tree-sitter heuristics.

Identifies where a variable is defined and modified, using a combination of tree-sitter pattern matching and simple backward-slice heuristics.

Structs

DataflowHop
A hop in the dataflow trace.
DataflowOrigin
A dataflow origin: where a value comes from.
DataflowTracer
Traces data flow for a variable up to max_hops hops backward.