Module experience_sampling

Module experience_sampling 

Experience pool summary generation via sampling.

Post-edit, generates a summary of the diff and affected files for storage in the experience pool. Falls back to listing raw file associations when sampling is unavailable.

Functions

summarize_edit
Generate a summary of an edit event for the experience pool.