file_score

Function file_score 

pub fn file_score(path: &str, query_words: &[String]) -> f32
Score a file path by the proportion of query words that appear in it.

A query word matches when the path contains it as a substring or when the path contains a word that starts with the query word (prefix match), allowing “auth” in a path to match the query word “authentication”.

Returns a value in [0.0, 1.0].