Module sampling

Module sampling 

Direct model sampling provider.

Uses the configured chat model directly for standalone (non-MCP) mode. When running the agent without an MCP host this provider is used in place of McpSampling from the MCP server crate.

Structs

DirectModelSampling
A sampling provider backed by direct model invocation.

Type Aliases

SamplingFn
Type alias for the callback used to invoke a language model.