#[non_exhaustive]pub struct MountedRepo {
pub url: String,
pub local_path: PathBuf,
pub indexed: bool,
}Expand description
Records a repository that was cloned and mounted during a session.
Stored in session state so that cloned repositories can be re-mounted automatically when a session is resumed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringRemote URL the repository was cloned from.
local_path: PathBufLocal path to the cloned repository on disk.
indexed: boolWhether the repository has been semantically indexed.
Implementations