Module meta

Module meta 

meta.* tool provider for tool discovery and introspection.

These opt-in tools allow the agent to search for and list available tools at runtime, supporting progressive disclosure of large tool suites.

Functions

meta_tool_provider
Build a tool provider for meta.* tools (opt-in).