#[non_exhaustive]pub struct CloneOptions {
pub url: String,
pub depth: Option<u32>,
pub ref: Option<String>,
pub index: bool,
}Expand description
Options controlling how a repository is cloned or updated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringRemote URL to clone from.
depth: Option<u32>Shallow clone depth. None performs a full clone.
ref: Option<String>Branch, tag, or commit ref to check out after cloning.
index: boolWhether to trigger semantic indexing after a successful clone.
Implementations