Module composite

Module composite 

Composite VFS provider routing by path prefix.

Structs

CompositeProvider
Routes operations to the provider whose prefix is the longest match.
Mount
A single mount point mapping a path prefix to a backend.